@@ -42,10 +42,6 @@ var (
 	)
 )
 
-func warnDeprecated(collector string) {
-	log.Warnf("The %s collector is deprecated and will be removed in the future!", collector)
-}
-
 const (
 	defaultEnabled  = true
 	defaultDisabled = false
@@ -75,12 +71,23 @@ func registerCollector(collector string, isDefaultEnabled bool, factory func() (
 }
 
 // NodeCollector implements the prometheus.Collector interface.
-type nodeCollector struct {
+type NodeCollector struct {
 	Collectors map[string]Collector
 }
 
-// NewNodeCollector creates a new NodeCollector
-func NewNodeCollector() (*nodeCollector, error) {
+// NewNodeCollector creates a new NodeCollector.
+func NewNodeCollector(filters ...string) (*NodeCollector, error) {
+	f := make(map[string]bool)
+	for _, filter := range filters {
+		enabled, exist := collectorState[filter]
+		if !exist {
+			return nil, fmt.Errorf("missing collector: %s", filter)
+		}
+		if !*enabled {
+			return nil, fmt.Errorf("disabled collector: %s", filter)
+		}
+		f[filter] = true
+	}
 	collectors := make(map[string]Collector)
 	for key, enabled := range collectorState {
 		if *enabled {
@@ -88,20 +95,22 @@ func NewNodeCollector() (*nodeCollector, error) {
 			if err != nil {
 				return nil, err
 			}
-			collectors[key] = collector
+			if len(f) == 0 || f[key] {
+				collectors[key] = collector
+			}
 		}
 	}
-	return &nodeCollector{Collectors: collectors}, nil
+	return &NodeCollector{Collectors: collectors}, nil
 }
 
 // Describe implements the prometheus.Collector interface.
-func (n nodeCollector) Describe(ch chan<- *prometheus.Desc) {
+func (n NodeCollector) Describe(ch chan<- *prometheus.Desc) {
 	ch <- scrapeDurationDesc
 	ch <- scrapeSuccessDesc
 }
 
 // Collect implements the prometheus.Collector interface.
-func (n nodeCollector) Collect(ch chan<- prometheus.Metric) {
+func (n NodeCollector) Collect(ch chan<- prometheus.Metric) {
 	wg := sync.WaitGroup{}
 	wg.Add(len(n.Collectors))
 	for name, c := range n.Collectors {
