@@ -25,19 +25,19 @@ type conntrackCollector struct {
 }
 
 func init() {
-	Factories["conntrack"] = NewConntrackCollector
+	registerCollector("conntrack", defaultEnabled, NewConntrackCollector)
 }
 
 // NewConntrackCollector returns a new Collector exposing conntrack stats.
 func NewConntrackCollector() (Collector, error) {
 	return &conntrackCollector{
 		current: prometheus.NewDesc(
-			prometheus.BuildFQName(Namespace, "", "nf_conntrack_entries"),
+			prometheus.BuildFQName(namespace, "", "nf_conntrack_entries"),
 			"Number of currently allocated flow entries for connection tracking.",
 			nil, nil,
 		),
 		limit: prometheus.NewDesc(
-			prometheus.BuildFQName(Namespace, "", "nf_conntrack_entries_limit"),
+			prometheus.BuildFQName(namespace, "", "nf_conntrack_entries_limit"),
 			"Maximum size of connection tracking table.",
 			nil, nil,
 		),
