@@ -38,11 +38,7 @@ func TestDiskStats(t *testing.T) {
 		t.Errorf("want diskstats mmcblk0p2 %s, got %s", want, got)
 	}
 
-	if want, got := "513713216512", diskStats["sda"][11]; want != got {
-		t.Errorf("want diskstats sda read bytes %s, got %s", want, got)
-	}
-
-	if want, got := "258916880384", diskStats["sda"][12]; want != got {
-		t.Errorf("want diskstats sda write bytes %s, got %s", want, got)
+	if want, got := "11130", diskStats["sdb"][14]; want != got {
+		t.Errorf("want diskstats sdb %s, got %s", want, got)
 	}
 }
