@@ -39,48 +39,39 @@ func NewExecCollector() (Collector, error) {
 	// vm.stats.sys.v_intr: Device interrupts
 	// vm.stats.sys.v_soft: Software interrupts
 	// vm.stats.vm.v_forks: Number of fork() calls
-	//
-	// From sys/kern/kern_tc.c:
-	// kern.boottime is an S,timeval
 
 	return &execCollector{
 		sysctls: []bsdSysctl{
 			{
-				name:        "context_switches_total",
-				description: "Context switches since system boot.  Resets at architeture unsigned integer.",
+				name:        "exec_context_switches_total",
+				description: "Context switches since system boot.  Resets at architecture unsigned integer.",
 				mib:         "vm.stats.sys.v_swtch",
 			},
 			{
-				name:        "traps_total",
-				description: "Traps since system boot.  Resets at architeture unsigned integer.",
+				name:        "exec_traps_total",
+				description: "Traps since system boot.  Resets at architecture unsigned integer.",
 				mib:         "vm.stats.sys.v_trap",
 			},
 			{
-				name:        "system_calls_total",
-				description: "System calls since system boot.  Resets at architeture unsigned integer.",
+				name:        "exec_system_calls_total",
+				description: "System calls since system boot.  Resets at architecture unsigned integer.",
 				mib:         "vm.stats.sys.v_syscall",
 			},
 			{
-				name:        "device_interrupts_total",
-				description: "Device interrupts since system boot.  Resets at architeture unsigned integer.",
+				name:        "exec_device_interrupts_total",
+				description: "Device interrupts since system boot.  Resets at architecture unsigned integer.",
 				mib:         "vm.stats.sys.v_intr",
 			},
 			{
-				name:        "software_interrupts_total",
-				description: "Software interrupts since system boot.  Resets at architeture unsigned integer.",
+				name:        "exec_software_interrupts_total",
+				description: "Software interrupts since system boot.  Resets at architecture unsigned integer.",
 				mib:         "vm.stats.sys.v_soft",
 			},
 			{
-				name:        "forks_total",
-				description: "Number of fork() calls since system boot.  Resets at architeture unsigned integer.",
+				name:        "exec_forks_total",
+				description: "Number of fork() calls since system boot.  Resets at architecture unsigned integer.",
 				mib:         "vm.stats.vm.v_forks",
 			},
-			{
-				name:        "boot_timestamp_seconds",
-				description: "Unix time of last boot, including microseconds.",
-				mib:         "kern.boottime",
-				dataType:    bsdSysctlTypeStructTimeval,
-			},
 		},
 	}, nil
 }
@@ -95,7 +86,7 @@ func (c *execCollector) Update(ch chan<- prometheus.Metric) error {
 
 		ch <- prometheus.MustNewConstMetric(
 			prometheus.NewDesc(
-				prometheus.BuildFQName(namespace, "exec", m.name),
+				namespace+"_"+m.name,
 				m.description,
 				nil, nil,
 			), prometheus.CounterValue, v)
