@@ -30,11 +30,11 @@ func TestMemInfo(t *testing.T) {
 		t.Fatal(err)
 	}
 
-	if want, got := 3831959552.0, memInfo["MemTotal"]; want != got {
+	if want, got := 3831959552.0, memInfo["MemTotal_bytes"]; want != got {
 		t.Errorf("want memory total %f, got %f", want, got)
 	}
 
-	if want, got := 3787456512.0, memInfo["DirectMap2M"]; want != got {
+	if want, got := 3787456512.0, memInfo["DirectMap2M_bytes"]; want != got {
 		t.Errorf("want memory directMap2M %f, got %f", want, got)
 	}
 }
