@@ -20,7 +20,6 @@ import (
 	"fmt"
 	"io"
 	"os"
-	"path"
 	"path/filepath"
 	"regexp"
 	"strconv"
@@ -47,7 +46,7 @@ type meminfoNumaCollector struct {
 }
 
 func init() {
-	Factories["meminfo_numa"] = NewMeminfoNumaCollector
+	registerCollector("meminfo_numa", defaultDisabled, NewMeminfoNumaCollector)
 }
 
 // NewMeminfoNumaCollector returns a new Collector exposing memory stats.
@@ -66,7 +65,7 @@ func (c *meminfoNumaCollector) Update(ch chan<- prometheus.Metric) error {
 		desc, ok := c.metricDescs[v.metricName]
 		if !ok {
 			desc = prometheus.NewDesc(
-				prometheus.BuildFQName(Namespace, memInfoNumaSubsystem, v.metricName),
+				prometheus.BuildFQName(namespace, memInfoNumaSubsystem, v.metricName),
 				fmt.Sprintf("Memory information field %s.", v.metricName),
 				[]string{"node"}, nil)
 			c.metricDescs[v.metricName] = desc
@@ -86,7 +85,7 @@ func getMemInfoNuma() ([]meminfoMetric, error) {
 		return nil, err
 	}
 	for _, node := range nodes {
-		meminfoFile, err := os.Open(path.Join(node, "meminfo"))
+		meminfoFile, err := os.Open(filepath.Join(node, "meminfo"))
 		if err != nil {
 			return nil, err
 		}
@@ -98,7 +97,7 @@ func getMemInfoNuma() ([]meminfoMetric, error) {
 		}
 		metrics = append(metrics, numaInfo...)
 
-		numastatFile, err := os.Open(path.Join(node, "numastat"))
+		numastatFile, err := os.Open(filepath.Join(node, "numastat"))
 		if err != nil {
 			return nil, err
 		}
