@@ -1,3 +1,16 @@
+// Copyright 2017 The Prometheus Authors
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+// http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+
 package main
 
 import (
@@ -129,14 +142,9 @@ func runCommandAndTests(cmd *exec.Cmd, address string, fn func(pid int) error) e
 		errc <- fn(pid)
 	}(cmd.Process.Pid)
 
-	select {
-	case err := <-errc:
-		if cmd.Process != nil {
-			cmd.Process.Kill()
-		}
-		if err != nil {
-			return err
-		}
+	err := <-errc
+	if cmd.Process != nil {
+		cmd.Process.Kill()
 	}
-	return nil
+	return err
 }
